eric7/Plugins/DocumentationPlugins/Ericdoc/EricdocConfigDialog.py

branch
eric7
changeset 8314
e3642a6a1e71
parent 8312
800c432b34c8
child 8318
962bce857696
--- a/eric7/Plugins/DocumentationPlugins/Ericdoc/EricdocConfigDialog.py	Sat May 15 19:01:16 2021 +0200
+++ b/eric7/Plugins/DocumentationPlugins/Ericdoc/EricdocConfigDialog.py	Sat May 15 20:08:03 2021 +0200
@@ -4,7 +4,7 @@
 #
 
 """
-Module implementing a dialog to enter the parameters for eric6_doc.
+Module implementing a dialog to enter the parameters for eric7_doc.
 """
 
 import sys
@@ -19,16 +19,16 @@
 
 from .Ui_EricdocConfigDialog import Ui_EricdocConfigDialog
 from DocumentationTools.Config import (
-    eric6docDefaultColors, eric6docColorParameterNames
+    eric7docDefaultColors, eric7docColorParameterNames
 )
 import Utilities
 
-from eric6config import getConfig
+from eric7config import getConfig
 
 
 class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
     """
     Class implementing a dialog to enter the parameters for eric6_doc.
     """
     def __init__(self, project, parms=None, parent=None):
         """
@@ -84,7 +84,7 @@
         
         # get a copy of the defaults to store the user settings
         self.parameters = copy.deepcopy(self.defaults)
-        self.colors = eric6docDefaultColors.copy()
+        self.colors = eric7docDefaultColors.copy()
         
         # combine it with the values of parms
         if parms is not None:
@@ -181,7 +181,7 @@
         # 1. the program name
         args.append(sys.executable)
         args.append(
-            Utilities.normabsjoinpath(getConfig('ericDir'), "eric6_doc.py"))
+            Utilities.normabsjoinpath(getConfig('ericDir'), "eric7_doc.py"))
         
         # 2. the commandline options
         # 2a. general commandline options
@@ -255,10 +255,10 @@
                 args.append(
                     os.path.join(self.ppath, self.parameters['cssFile']))
         for key in self.colors:
-            if self.colors[key] != eric6docDefaultColors[key]:
+            if self.colors[key] != eric7docDefaultColors[key]:
                 parms[key] = self.colors[key]
                 args.append("--{0}={1}".format(
-                    eric6docColorParameterNames[key], self.colors[key]))
+                    eric7docColorParameterNames[key], self.colors[key]))
         
         # 2c. QtHelp commandline options
         parms['qtHelpEnabled'] = self.parameters['qtHelpEnabled']
@@ -19,16 +19,16 @@
 class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
     """
-    Class implementing a dialog to enter the parameters for eric6_doc.
+    Class implementing a dialog to enter the parameters for eric7_doc.
     """
     def __init__(self, project, parms=None, parent=None):

eric ide

mercurial